@@ -5,6 +5,7 @@ from six.moves import configparser
 import os
 import subprocess
 import sys
+import re
 
 import six
 
@@ -28,7 +29,7 @@ def asbool(some_value):
 
 def aslist(value):
     """ Cast config values to lists of strings """
-    return [item.strip() for item in value.strip().split(',')]
+    return [item.strip() for item in re.split(",(?![^{]*})",value.strip())]
 
 
 def asint(value):
@@ -312,7 +313,9 @@ class ServiceConfig(object):
             if to_type:
                 return to_type(value)
             return value
-        except:
+        except configparser.NoSectionError:
+            return default
+        except configparser.NoOptionError:
             return default
 
     def _get_key(self, key):
