@@ -98,7 +98,7 @@ def hamdist(str1, str2):
     return diffs
 
 
-def get_managed_task_uuids(tw, key_list, legacy_matching):
+def get_managed_task_uuids(tw, key_list):
     expected_task_ids = set([])
     for keys in key_list.values():
         tasks = tw.filter_tasks({
@@ -112,18 +112,6 @@ def get_managed_task_uuids(tw, key_list, legacy_matching):
             task['uuid'] for task in tasks
         ])
 
-    if legacy_matching:
-        starts_with_markup = tw.filter_tasks({
-            'description.startswith': MARKUP,
-            'or': [
-                ('status', 'pending'),
-                ('status', 'waiting'),
-            ],
-        })
-        expected_task_ids = expected_task_ids | set([
-            task['uuid'] for task in starts_with_markup
-        ])
-
     return expected_task_ids
 
 
@@ -148,13 +136,12 @@ def make_unique_identifier(keys, issue):
     raise RuntimeError("Could not determine unique identifier for %s" % issue)
 
 
-def find_taskwarrior_uuid(tw, keys, issue, legacy_matching=False):
+def find_taskwarrior_uuid(tw, keys, issue):
     """ For a given issue issue, find its local taskwarrior UUID.
 
     Assembles a list of task IDs existing in taskwarrior
     matching the supplied issue (`issue`) on the combination of any
-    set of supplied unique identifiers (`keys`) or, optionally,
-    the task's description field (should `legacy_matching` be `True`).
+    set of supplied unique identifiers (`keys`).
 
     :params:
     * `tw`: An instance of `taskw.TaskWarriorShellout`
@@ -171,10 +158,6 @@ def find_taskwarrior_uuid(tw, keys, issue, legacy_matching=False):
         ]
 
     * `issue`: An instance of a subclass of `bugwarrior.services.Issue`.
-    * `legacy_matching`: By default, this is disabled, and it allows
-      the matching algorithm to -- in addition to searching by stored
-      issue keys -- search using the task's description for a match.
-      It is prone to error and should avoided if possible.
 
     :returns:
     * A single string UUID.
@@ -189,22 +172,6 @@ def find_taskwarrior_uuid(tw, keys, issue, legacy_matching=False):
 
     possibilities = set([])
 
-    if legacy_matching:
-        legacy_description = issue.get_default_description().rsplit('..', 1)[0]
-        # Furthermore, we have to kill off any single quotes which break in
-        # task-2.4.x, as much as it saddens me.
-        legacy_description = legacy_description.split("'")[0]
-        results = tw.filter_tasks({
-            'description.startswith': legacy_description,
-            'or': [
-                ('status', 'pending'),
-                ('status', 'waiting'),
-            ],
-        })
-        possibilities = possibilities | set([
-            task['uuid'] for task in results
-        ])
-
     for service, key_list in six.iteritems(keys):
         if any([key in issue for key in key_list]):
             results = tw.filter_tasks({
@@ -212,6 +179,7 @@ def find_taskwarrior_uuid(tw, keys, issue, legacy_matching=False):
                 'or': [
                     ('status', 'pending'),
                     ('status', 'waiting'),
+                    ('status', 'completed')
                 ],
             })
             possibilities = possibilities | set([
@@ -234,6 +202,43 @@ def find_taskwarrior_uuid(tw, keys, issue, legacy_matching=False):
     )
 
 
+def replace_left(field, local_task, remote_issue, keep_items=[]):
+    """ Replace array field from the remote_issue to the local_task
+
+    * Local 'left' entries are suppressed, unless those listed in keep_items.
+    * Remote 'left' are appended to task, if not present in local.
+    
+    :param `field`: Task field to merge.
+    :param `local_task`: `taskw.task.Task` object into which to replace
+        remote changes.
+    :param `remote_issue`: `dict` instance from which to add into
+        local task.
+    :param `keep_items`: list of items to keep into local_task even if not 
+        present in remote_issue
+    """
+
+    # Ensure that empty default are present
+    local_field = local_task.get(field, []).copy()
+    remote_field = remote_issue.get(field, [])
+
+    # We need to make sure an array exists for this field because
+    # we will be appending to it in a moment.
+    if field not in local_task:
+        local_task[field] = []
+
+    #Delete all items in local_task, unless they are in keep_items or in remote_issue
+    #This ensure that the task is not being updated if there is no changes
+    for item in local_field:
+        if keep_items.count(item) == 0 and remote_field.count(item) == 0:
+            log.debug('found %s to remove' % (item))
+            local_task[field].remove(item)
+        elif remote_field.count(item) > 0:
+            remote_field.remove(item)
+
+    if len(remote_field) > 0:
+        local_task[field] += remote_field
+
+
 def merge_left(field, local_task, remote_issue, hamming=False):
     """ Merge array field from the remote_issue into local_task
 
@@ -291,7 +296,7 @@ def run_hooks(conf, name):
         if pre_import is not None:
             for hook in pre_import:
                 exit_code = subprocess.call(hook, shell=True)
-                if exit_code is not 0:
+                if exit_code != 0:
                     msg = 'Non-zero exit code %d on hook %s' % (
                         exit_code, hook
                     )
@@ -333,15 +338,19 @@ def synchronize(issue_generator, conf, main_section, dry_run=False):
         marshal=True,
     )
 
-    legacy_matching = _bool_option(main_section, 'legacy_matching', False)
     merge_annotations = _bool_option(main_section, 'merge_annotations', True)
     merge_tags = _bool_option(main_section, 'merge_tags', True)
+    replace_tags = _bool_option(main_section, 'replace_tags', False)
+
+    static_tags = []
+    if conf.has_option(main_section, 'static_tags'):
+        static_tags = aslist(conf.get(main_section, 'static_tags'))
 
     issue_updates = {
         'new': [],
         'existing': [],
         'changed': [],
-        'closed': get_managed_task_uuids(tw, key_list, legacy_matching),
+        'closed': get_managed_task_uuids(tw, key_list),
     }
 
     seen = []
@@ -372,11 +381,14 @@ def synchronize(issue_generator, conf, main_section, dry_run=False):
                 continue
             seen.append(unique_identifier)
 
-            existing_taskwarrior_uuid = find_taskwarrior_uuid(
-                tw, key_list, issue, legacy_matching=legacy_matching
-            )
+            existing_taskwarrior_uuid = find_taskwarrior_uuid(tw, key_list, issue)
             _, task = tw.get_task(uuid=existing_taskwarrior_uuid)
 
+            if task['status'] == 'completed':
+                # Reopen task
+                task['status'] = 'pending'
+                task['end'] = None
+
             # Drop static fields from the upstream issue.  We don't want to
             # overwrite local changes to fields we declare static.
             for field in static_fields:
@@ -388,7 +400,10 @@ def synchronize(issue_generator, conf, main_section, dry_run=False):
                 merge_left('annotations', task, issue_dict, hamming=True)
 
             if merge_tags:
-                merge_left('tags', task, issue_dict)
+                if replace_tags:
+                    replace_left('tags', task, issue_dict, static_tags)
+                else:
+                    merge_left('tags', task, issue_dict)
 
             issue_dict.pop('annotations', None)
             issue_dict.pop('tags', None)
@@ -413,6 +428,7 @@ def synchronize(issue_generator, conf, main_section, dry_run=False):
     log.info("Adding %i tasks", len(issue_updates['new']))
     for issue in issue_updates['new']:
         log.info(u"Adding task %s%s", issue['description'], notreally)
+
         if dry_run:
             continue
         if notify:
