@@ -5,9 +5,6 @@ import pytz
 import datetime
 import six
 
-from dateutil.parser import parse as parse_date
-from dateutil.tz import tzlocal
-
 from bugwarrior.config import die, asbool, aslist
 from bugwarrior.services import IssueService, Issue
 
@@ -83,11 +80,10 @@ class BugzillaIssue(Issue):
             self.COMPONENT: self.record['component'],
         }
         if self.extra.get('needinfo_since', None) is not None:
-            task[self.NEEDINFO] = self.extra.get('needinfo_since')
+            task[self.NEEDINFO] = self.parse_date(self.extra.get('needinfo_since'))
 
-        # iff field is defined, use it, converting None to empty string.
-        if 'assigned_on' in self.extra:
-            task[self.ASSIGNED_ON] = self.extra.get('assigned_on') or ''
+        if self.extra.get('assigned_on', None) is not None:
+            task[self.ASSIGNED_ON] = self.parse_date(self.extra.get('assigned_on'))
 
         return task
 
@@ -127,6 +123,7 @@ class BugzillaService(IssueService):
         'component',
         'flags',
         'longdescs',
+        'assigned_to',
     ]
 
     def __init__(self, *args, **kw):
@@ -134,7 +131,7 @@ class BugzillaService(IssueService):
         self.base_uri = self.config.get('base_uri')
         self.username = self.config.get('username')
         self.ignore_cc = self.config.get('ignore_cc', default=False,
-                                                 to_type=lambda x: x == "True")
+                                         to_type=lambda x: x == "True")
         self.query_url = self.config.get('query_url', default=None)
         self.include_needinfos = self.config.get(
             'include_needinfos', False, to_type=lambda x: x == "True")
@@ -149,16 +146,20 @@ class BugzillaService(IssueService):
         # to pass that argument or not.
         self.advanced = asbool(self.config.get('advanced', 'no'))
 
-        url = 'https://%s/xmlrpc.cgi' % self.base_uri
-        api_key = self.config.get('api_key', default=None)
-        if api_key:
+        force_rest_kwargs = {}
+        if asbool(self.config.get("force_rest", "no")):
+            force_rest_kwargs = {"force_rest": True}
+
+        url = 'https://%s' % self.base_uri
+        if self.config.get('api_key'):
+            api_key = self.get_password('api_key')
             try:
-                self.bz = bugzilla.Bugzilla(url=url, api_key=api_key)
+                self.bz = bugzilla.Bugzilla(url=url, api_key=api_key, **force_rest_kwargs)
             except TypeError:
                 raise Exception("Bugzilla API keys require python-bugzilla>=2.1.0")
         else:
             password = self.get_password('password', self.username)
-            self.bz = bugzilla.Bugzilla(url=url)
+            self.bz = bugzilla.Bugzilla(url=url, **force_rest_kwargs)
             self.bz.login(self.username, password)
 
     @staticmethod
@@ -179,9 +180,7 @@ class BugzillaService(IssueService):
         super(BugzillaService, cls).validate_config(service_config, target)
 
     def get_owner(self, issue):
-        # NotImplemented, but we should never get called since .include() isn't
-        # used by this IssueService.
-        raise NotImplementedError
+        return issue['assigned_to']
 
     def annotations(self, tag, issue, issue_obj):
         base_url = "https://%s/show_bug.cgi?id=" % self.base_uri
@@ -268,6 +267,7 @@ class BugzillaService(IssueService):
             ) for bug in bugs
         ]
 
+        bugs = filter(self.include, bugs)
         issues = [(self.target, bug) for bug in bugs]
         log.debug(" Found %i total.", len(issues))
 
@@ -280,16 +280,18 @@ class BugzillaService(IssueService):
                 'annotations': self.annotations(tag, issue, issue_obj),
             }
 
-            needinfos = [f for f in issue['flags'] if (    f['name'] == 'needinfo'
-                                          and f['status'] == '?'
-                                          and f.get('requestee', self.username) == self.username)]
+            needinfos = [f for f in issue['flags'] if (
+                f['name'] == 'needinfo' and
+                f['status'] == '?' and
+                f.get('requestee', self.username) == self.username
+            )]
             if needinfos:
                 last_mod = needinfos[0]['modification_date']
                 # convert from RPC DateTime string to datetime.datetime object
                 mod_date = datetime.datetime.fromtimestamp(
                     time.mktime(last_mod.timetuple()))
 
-                extra['needinfo_since'] = pytz.UTC.localize(mod_date)
+                extra['needinfo_since'] = pytz.UTC.localize(mod_date).isoformat()
 
             if issue['status'] == 'ASSIGNED':
                 extra['assigned_on'] = self._get_assigned_date(issue)
@@ -303,20 +305,21 @@ class BugzillaService(IssueService):
         assigned_date = None
 
         bug = self.bz.getbug(issue['id'])
-        history = bug.get_history()['bugs'][0]['history']
+        history = bug.get_history_raw()['bugs'][0]['history']
 
         # this is already in chronological order, so the last change is the one we want
-        h = history[-1]
-        for change in h['changes']:
-            if change['field_name'] == 'status' and change['added'] == 'ASSIGNED':
-              assigned_date = h['when']
+        for h in reversed(history):
+            for change in h['changes']:
+                if change['field_name'] == 'status' and change['added'] == 'ASSIGNED':
+                    assigned_date = h['when']
 
-        # messy conversion :(
-        # TODO: create method that's used here and in needinfos time conv above
-        assigned_date_datetime = datetime.datetime.fromtimestamp(time.mktime(assigned_date.timetuple()))
-        assigned_date_str = pytz.UTC.localize(assigned_date_datetime).isoformat()
+                    # messy conversion :(
+                    # TODO: create method that's used here and in needinfos time conv above
+                    assigned_date_datetime = datetime.datetime.fromtimestamp(
+                        time.mktime(assigned_date.timetuple()))
+                    assigned_date_str = pytz.UTC.localize(assigned_date_datetime).isoformat()
 
-        return assigned_date_str
+                    return assigned_date_str
 
 
 def _get_bug_attr(bug, attr):
