@@ -2,7 +2,6 @@ from __future__ import absolute_import
 
 import requests
 import six
-import sys
 from bugwarrior.db import CACHE_REGION as cache
 from bugwarrior.config import die
 from bugwarrior.services import IssueService, Issue, ServiceClient
@@ -45,7 +44,7 @@ class TaigaIssue(Issue):
         }
 
     def get_tags(self):
-        return [x if isinstance(x, str if sys.version_info[0] >= 3 else basestring) else x[0] for x in self.record['tags']]
+        return [x if isinstance(x, six.string_types) else x[0] for x in self.record['tags']]
 
     def get_default_description(self):
         return self.build_default_description(
