@@ -1,7 +1,7 @@
 from builtins import next
 from builtins import str
 from builtins import object
-import mock
+from unittest import mock
 
 from bugwarrior.services import bts
 
