@@ -2,9 +2,9 @@ from __future__ import unicode_literals, print_function
 from future import standard_library
 standard_library.install_aliases()
 from builtins import next
+from unittest.mock import patch
 
 from six.moves import configparser
-from mock import patch
 import responses
 
 from dateutil.parser import parse as parse_date
@@ -25,6 +25,7 @@ class TestTrelloIssue(ServiceTest):
         "shortUrl": "https://trello.com/c/AAaaBBbb",
         "url": "https://trello.com/c/AAaBBbb/42-so-long",
         "labels": [{'name': "foo"}, {"name": "bar"}],
+        "desc": "some description",
         }
 
     def setUp(self):
@@ -55,6 +56,7 @@ class TestTrelloService(ConfigTest):
              'idShort': 1,
              'shortLink': 'abcd',
              'shortUrl': 'https://trello.com/c/AAaaBBbb',
+             'desc': 'some description',
              'url': 'https://trello.com/c/AAaBBbb/42-so-long'}
     CARD2 = {'id': 'kard', 'name': 'Card 2', 'members': [{'username': 'mario'}]}
     CARD3 = {'id': 'K4rD', 'name': 'Card 3', 'members': []}
@@ -189,6 +191,8 @@ class TestTrelloService(ConfigTest):
             'trellolist': 'List 1',
             'trellocard': 'Card 1',
             'trellocardid': 'C4RD',
+            'trellocardidshort': 1,
+            'trellodescription': 'some description',
             'trelloshortlink': 'abcd',
             'trelloshorturl': 'https://trello.com/c/AAaaBBbb',
             'trellourl': 'https://trello.com/c/AAaBBbb/42-so-long',
@@ -217,3 +221,10 @@ class TestTrelloService(ConfigTest):
         self.config.remove_option('mytrello', 'trello.api_key')
         TrelloService.validate_config(self.service_config, 'mytrello')
         die.assert_called_with("[mytrello] has no 'trello.api_key'")
+
+
+    def test_keyring_service(self):
+        """ Checks that the keyring service name """
+        keyring_service = TrelloService.get_keyring_service(self.service_config)
+        self.assertEqual("trello://XXXX@trello.com", keyring_service)
+
